changeset 9578:6710e111fa6a octave-forge

control-devel: return size of iddata properties
author paramaniac
date Wed, 07 Mar 2012 13:22:39 +0000
parents 6bf3b8edb16f
children 431cb6fb9081
files extra/control-devel/inst/@iddata/__property_names__.m
diffstat 1 files changed, 12 insertions(+), 10 deletions(-) [+]
line wrap: on
line diff
--- a/extra/control-devel/inst/@iddata/__property_names__.m	Wed Mar 07 12:45:17 2012 +0000
+++ b/extra/control-devel/inst/@iddata/__property_names__.m	Wed Mar 07 13:22:39 2012 +0000
@@ -16,8 +16,8 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {[@var{props}, @var{vals}] =} __property_names__ (@var{sys})
 ## Return the list of properties as well as the assignable values for an LTI object sys.
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -26,6 +26,8 @@
 
 function [props, vals] = __property_names__ (dat)
 
+  [n, p, m, e] = size (dat);
+
   ## cell vector of iddata-specific properties
   props = {"y";
            "outname";
@@ -41,15 +43,15 @@
            "userdata"};
 
   ## cell vector of lti-specific assignable values
-  vals = {"p-by-1 cell vector of matrices";
-          "p-by-1 cell vector of strings";
-          "p-by-1 cell vector of strings";
-          "m-by-1 cell vector of matrices";
-          "m-by-1 cell vector of strings";
-          "m-by-1 cell vector of strings";
-          "scalar (sample time in seconds)";
+  vals = {sprintf("(%dx1) cell vector of (nx%d) matrices", e, p);
+          sprintf("(%dx1) cell vector of strings", p);
+          sprintf("(%dx1) cell vector of strings", p);
+          sprintf("(%dx1) cell vector of (nx%d) matrices", e, m);
+          sprintf("(%dx1) cell vector of strings", m);
+          sprintf("(%dx1) cell vector of strings", m);
+          sprintf("(%dx1) cell vector of scalars", e);
           "string";
-          "e-by-1 cell vector of strings";
+          sprintf("(%dx1) cell vector of strings", e);
           "string";
           "string or cell of strings";
           "any data type"};
@@ -16,8 +16,8 @@
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{props}, @var{vals}] =} __property_names__ (@var{sys})
-## Return the list of properties as well as the assignable values for an LTI object sys.
+## @deftypefn {Function File} {[@var{props}, @var{vals}] =} __property_names__ (@var{dat})
+## Return the list of properties as well as the assignable values for an iddata set.
 ## @end deftypefn
 